%% single_bvp_ode
function dxdt=single_bvp_ode(t,x)

%% 1. Number of cells per one model's segment and cell volume
	NFc			= 168;	% fibrocyte
	NIm			= 16;	% intermediate
	NMc			= 40;	% marginal-cell
	NHc			= 3;	% hair-cell
	% `Ă
	R			= 8.31447;							% Gas constant		(J/K*mol)
	T			= 310.15;							% Temperature		(Kelvin)
	F			= 96485;							% Faraday constant	(C/mol)

	WPL			= 350       *10^(-10);              % Volume of perilymph	(l)
	WSY			= 350       *10^(-15);				% Volume of syncytium	(l)
	WIS			= 21        *10^(-12);				% Volume of intrastrial	(l)
	WMC			= 350       *10^(-15);				% Volume of marginal-cell	(l)
	WEL			= 350       *10^(-12);				% Volume of endolymph	(l)
	WHC			= 350       *10^(-15);				% Volume of hair-cell	(l) 

    CFc         = 5*10^( -8);                       % Capacitance of fibrocytes (F)
	CIm			= 5*10^(-11);						% Capacitance of intermediate (F)
	CMb			= 5*10^(-11);						% Capacitance of marginal-baso (F)
	CMa			= 5*10^(-13);						% Capacitance of marginal-api	(F)
	CHb			= 5*10^(-12);						% Capacitance of hair-baso (F)

GNaKATPFc       =   2.2   *10^(-11);                 % conductance of NaKATP fibrocyte
GNCFc           =   0.6   *10^(-9);                  % conductance of NSC channel
GKFc            =   0     *10^(-12);                  % conductance of K channel
GNaFc           =   1.2   *10^(-9);   

GKIm		    = 147    *10^(-9);					% K   conductance of intermediate	(nS)
%GKvIm          =   0    *10^(-9);                  % Kv conductance of intermediate  (nS)
GNCIm           =  12    *10^(-9);                  % NSC conductance of intermediate (nS)

GNaKATPMb	    =   0.11 *10^(-9);                  % (block)*conductance of NaKATP marginal-baso
PNKCCMb		    =   0.1  *10^(-12);                 % NKCC rate
GClMb		    = 100    *10^(-9);                  % Cl  conductance of marginal-baso	(S)
GNCMb		    =   1    *10^(-9);                  % NSC conductance of marginal-baso	(S)

GKMa		    =  32    *10^(-9);                  % K   conductance of marginal-api	(S)
GNCMa           =   2    *10^(-9);                  % NSC conductance of marginal-api (S)

GKHa		    =   6.4  *10^(-9);                  % K   conductance of hair-api		(S)
GKHb		    =  40    *10^(-9);                  % K   conductance of hair-baso		(S)

          

	KNa			= 0.04469;							% Constant in NKCC1 Equation
	KK			= 0.00426;							% Constant in NKCC1 Equation
	KCl			= 0.41329;							% Constant in NKCC1 Equation
	KfFull		= 1.406;							% Constant in NKCC1 Equation
	KbFull		= 4.025;							% Constant in NKCC1 Equation

	dxdt		= zeros(26,1);					


%% 2. Current of channels and transporters
%% 2-1. Na+K+-ATPases Current in the Fibrocytes
	
	SGFc				=	( exp( 1000 * x(22) / 67.3 )  -1 ) / 7;	%  fibrocyte

	fNaKATPFc			= 	1 ...
							/ ( ...
								1 ...
								+ 0.1245 * exp(  -0.1 *x(01) * F / ( R * T ) ) ...
								+ 0.0365 * SGFc * exp( -x(01) * F / ( R * T ) ) ...
							);

	INaKATPFc			=	GNaKATPFc ...
								*block2(t) ...
								* ( fNaKATPFc / ( 1 + ( 0.01 / x(23) )^1.5 ) ) ...
								* ( x(06) / ( x(06) + 0.0015 ) );		% transporter K current (܂ NaKATP K current);

    IKNaKATPFc          =         -2 * INaKATPFc;
    INaNaKATPFc         =         +3 * INaKATPFc;

%% 2-1-2. NSC Current in the Fibrocytes

    INCFc               =   GNCFc * ( x(01) - ( R * T / F )* log( ( x(06)+ x(22) ) / ( x(07)+ x(23) ) ) );                            
        
%% 2-1-2. K channel Current on Membrane of the Fibrocytes

    IKFc                =   GKFc  * ( x(01)- ( R * T / F )*log( x(06) / x(07)) );

%% 2-1-3. Na channel Current on Membrane of the Fibrocytes

    INaFc               =   GNaFc * ( x(01)- ( R * T / F )*log( x(22) / x(23)) );
          
%% 2-2. Kir4.1 Current in the Intermediate Cells
	IKIm_sub1			=	x(02) - ( R * T / F ) * log( x(08) / x(07) );
	IKIm				=	GKIm ...
								* bablock(t) ...
								* ( ( x(08) / 0.0054 )^(0.5) ) ...
								* ( 1 / ( 1 + exp( ( x(02) + 0.0592 ) / 0.0485 ) ) )...
								* IKIm_sub1;

%% 2-2.-1 Kv-channels' Current on Intermediate cells

%   IKvIm_sub1			=	x(02) - ( R * T / F ) * log( x(08) / x(07) );
%	IKvIm				=	GKvIm ...
%								* bablock1(t) ...
%								* ( 1 / ( 1 + exp( ( x(02) + 0.0512 ) / (-0.0266) ) ) )...
%								* IKvIm_sub1;

 %% 2-2.-2 Non-selective Cation channels' Current on Intermediate cells

    INCIm               =   GNCIm * ( x(02) - ( R * T / F )* log( ( x(08)+ x(18) ) / ( x(07)+ x(23) ) ) );                                                                    
%% 2-3. ClCs' Current on the Basolateral Membrane of the Marginal Cells

	IClMb				=	GClMb * ( x(03) - ( R * T / F )*log( x(15) / x(14)) );		% IClMb (VMb-EClMb(ClMc/ClIS))

%% 2-4. Non-selective Cation channels' Current on the Basolateral Membrane of the Marginal Cells
	
	INCMb				=	GNCMb * ( x(03) - ( R * T / F ) * log( ( x(08) + x(18) ) / ( x(09) + x(19) ) ) );

%% 2-5. Na+K+_ATPases' Current on the Basolateral Membrane of the Marginal Cells
	SGMb				=	( ( exp( ( 1000 * x(18) ) / 67.3 ) ) -1 ) / 7;	% marginal-baso

	fNaKATPMb			=	1 ...
							/ ( ...
								1 ...
								+ 0.1245 * exp( -0.1 * x(03) * F / ( R * T ) ) 		...
								+ 0.0365 * ( SGMb ) * exp( -(x(03) ) * F / (R*T) )	...
							);

	INaKATPMb			=	GNaKATPMb * block(t) ...
								* ( fNaKATPMb / ( 1 + ( 0.01 / ( x(19) ) )^1.5 ) )	...
								* ( x(08) / ( x(08) + 0.0015 ) );	% transporter K current (܂ NaKATP K current);

	IKNaKATPMb			=	-2 * INaKATPMb;
	INaNaKATPMb			=	3 * INaKATPMb;

%% 2-6. NKCC1s' Current on the Basolateral Membrane of the Marginal Cells
	NKCC_sub1			=	KNa * 1000 * x(18) * KCl * 1000 * x(14) * KK * 1000 * x(08) * KCl * 1000 * x(14);
	NKCC_sub2			=	KNa * 1000 * x(19) * KCl * 1000 * x(15) * KK * 1000 * x(09) * KCl * 1000 * x(15);

	p_E1				=	1 ...
							/ ( ...
								1 ...
								+ KNa * 1000 * x(18) ...
								+ KNa * 1000 * x(18) * KCl * 1000 * x(14) ...
								+ KNa * 1000 * x(18) * KCl * 1000 * x(14) * KK * 1000 * x(08) ...
								+ NKCC_sub1 ...
							);

	p_E2				=	1 ...
							/ ( ...
								1 ...
								+ KCl * 1000 * x(15) ...
								+ KCl * 1000 * x(15) * KK * 1000 * x(09) ...
								+ KCl * 1000 * x(15) * KK * 1000 * x(09) * KCl * 1000 * x(15) ...
								+ NKCC_sub2 ...
							);

	p_E1NaClKCl			=	NKCC_sub1 * p_E1;
	p_E2NaClKCl			=	NKCC_sub2 * p_E2;




	INKCCMb				=	(-3) * block(t)	...
								* F * PNKCCMb	...
								* ( ...
									(   KfFull * p_E1NaClKCl ) .* x(21)				...	% KfFull * p(E1NaClKCl) * y
									- ( KbFull * p_E2NaClKCl ) .* ( 1 - x(21) )		...	% KbFull * p(E2NaClKCl) * ( 1 - y )
								);
	IKNKCCMb			=	INKCCMb;
	INaNKCCMb			=	INKCCMb;
	IClNKCCMb			=	-2 * INKCCMb;



%% 2-7. KCNQ1/KCNE1 Current on the Apical Membrane of the Marginal Cells

    IKma				=	GKMa  * ( x(20) ) * ( x(04) - ( R * T / F ) * log( x(10) / x(09) ) );

%% 2-7.-1 Non-selective Cation channels' Current on Ma

    INCMa               =   GNCMa * ( x(04) - ( R * T / F )* log( ( x(10)+ x(24) ) / ( x(09)+ x(19) ) ) );
    
%% 2-8. Mechanochannels' Current

    IKHa				=	GKHa  * ( -x(01)+x(02)-x(03)+x(04)+x(05) -( R * T / F )*log( x(10) / x(11)) );

%% 2-9. Potassium Ion Channels' Current on the Basolateral Membrane of the Hair Cells

    IKHb				=	GKHb *(x(05)- ( R * T / F )*log( x(06) / x(11)) );			% IKHb (VHb-EKHb(KPL/KHc))

%% 2-10. Alternation of NSC current Mb
	jdg_K				=	judgeK ( x(03), x(08), x(18), x(09), x(19), R, T, F );
	jdg_Na				=	judgeNa( x(03), x(08), x(18), x(09), x(19), R, T, F );
%% 2-11. Alternation of NSC current Fc
	jdg_KFc				=	judgeKFc ( x(01), x(06), x(22), x(07), x(23), R, T, F );
	jdg_NaFc            =	judgeNaFc( x(01), x(06), x(22), x(07), x(23), R, T, F );
    
%% 3. Differential equations of voltage change
%% Current ODE ( dv / dt )
	% fibrocytedODE(VFc)
	dxdt(01)	=   (...
                       + NHc * IKHa         ...
                       - NFc * (...
                                  + INaKATPFc ...         % NaKATPFc current
                                  + INaFc       ...       % Na channle current
                                  + INCFc ...           % NSC channle current
                               )...       
                     ) ...
			 		/ ( NFc * CFc );		

	%intermediatedODE(VIm)
	dxdt(02)	=	( ...
                        - NHc * IKHa ...
                        - NIm * (IKIm )  ...
                        - NIm * (INCIm * (x(08)/(x(08)+x(18) )) ) ...  
                    )...
					/ ( NIm * CIm );	

	%marginal-basodODE(VMb)
	dxdt(03)	=	( ...
						+ NHc * IKHa	...
						- NMc * ( + IClMb + INCMb + INaKATPMb ) ...
					) ...
					/ ( NMc * CMb ); 

	% marginal-apidODE(VMa)
	dxdt(04)	=	( ...
						- NHc * IKHa	...
						- NMc *(IKma)	...	
                        - NMc *(INCMa* (x(09)/(x(09)+x(19) )  )  )  )...
					/ ( NMc * CMa );

	% hair-basodODE(VHb)
	dxdt(05)	=	( ...
						(-NHc) ...
							* ( ...
								IKHa		...	% Silent current
								+ IKHb		...	% IKHb (VHb-EKHb(KPL/KHc))
							) ...
					) / ( CHb * NHc );
% 



%% 4. Differential equations of concentration change
%% K-Concentration ODE
	dxdt(06)	=	( ...
						+ NHc * IKHb                                ...	% IKHb (VHb-EKHb(KPL/KHc))
						+ NFc                                       ...
                            *(                                      ...
                            + IKNaKATPFc                            ...	% NaKATPase current
                            + INCFc * jdg_KFc                        ... % INCFc
                             )...
					) ...
					/ ( F * WPL * 1);                                   % KZxPL


	dxdt(07)	=	-( ...
                        + NFc ...
                          * ( ...
                          + IKNaKATPFc                              ... % NaKATPFcK
                          + INCFc * jdg_KFc                          ... % INCFc
                            ) ... 
						+ NIm * ( IKIm )                            ... % Kir4.1
                        + NIm * ( INCIm* (x(08)/(x(08)+x(18))))     ... % NSC Im
					 ) ...
					/ ( F * WSY * NFc );                                % KZxSY

	dxdt(08)	=	( ...
						NIm * ( IKIm ) 		...                         % Kir4.1
                        + NIm * (INCIm * (x(08)/(x(08)+x(18) )) ) ...   %NSC Im
						+ NMc ... 
							* ( ...
								INCMb *jdg_K			...             % INCMbK
								+ IKNaKATPMb			...             % transporter K current
								+ IKNKCCMb	...
							) ...
					) ...
					/ ( F*WIS );                                    %KZxIS

	dxdt(09)	=	-( ...
						+ NMc ...
							* ( ...
								+ INCMb * jdg_K			...             % INCMbK
								+ IKNaKATPMb			...             % NaKATP K current
								+ IKNKCCMb				...
							) ...
						+ NMc * IKma					...             % IKMa (VMa-EKMa(KEL/KMc))
                        + NMc * INCMa * (x(09)/(x(09)+x(19) ) ) ...     % INC Ma
					) ...
					/ ( F * WMC * NMc );                                %KZxMC

	dxdt(10)	=	( ...
						+ NMc * IKma		...	% IKMa (VMa-EKMa(KEL/KMc))
                                                            + NMc * INCMa * (x(09)/(x(09)+x(19) ) )       ...       % INCMa
						+ NHc * IKHa		...	% IKHa
					) ...
					/ ( F * WEL * 1 );			% KZxEL

	dxdt(11)	=	( ...
						- (IKHa * (NHc))	...	% IKHa
						- (IKHb*( NHc))		...	% IKHb (VHb-EKHb(KPL/KHc))
					) / ( F * WHC * NHc );		%KZxHC

%% Cl-Concentration ODE
	dxdt(12)	=	0;
                                        
	dxdt(13)	=	0;

	dxdt(14)	=	-( ...
						+ NMc ...
                          * ( ...
                            + IClMb			...	% IClMb (VMb-EClMb(ClMc/ClIS))
						    + IClNKCCMb		...
                            ) ...
					 ) ...
					 / ( F * WIS );			%ClZxIS

	dxdt(15)	=	( ...
						+ NMc ...
                          * ( ...
                          + IClMb			...	% IClMb (VMb-EClMb(ClMc/ClIS))
						  + IClNKCCMb		...
                            ) ...
					) ...
					 / ( F * WMC * NMc );			%ClZxMC

	dxdt(16)	=	0;		%ClZxEL
	dxdt(17)	=	0;		%ClZxHC


%% Na Concentration ODE

	dxdt(18)	=	(   + NIm ... 
                          * ( ...
                            + INCIm * (x(18)/(x(08)+x(18) ))           ...
                            + (- INCIm * (x(18)/(x(08)+x(18) )) )      ...
                            ) ...
                        + NMc ...
                          * ( ...
                            + INCMb * jdg_Na                          ...
						    + INaNaKATPMb                             ...	% transporter K current
						    - (-INaNKCCMb)                            ...
                            ) ...
					) ...
					/ ( F * WIS  );                                    % NaZxIS

	dxdt(19)	=	(...
                        - NMc ...
                          *	( ...
                            + INCMb * jdg_Na                          ...	% INCMbNa
						    + INaNaKATPMb                             ...	% transporter K current
						    - (-INaNKCCMb)                            ...
                            ) ...
					) ...
					/ ( F * WMC * NMc );				% NaZxMC


%% IKs time dependent

	dxdt(20)	=	+ alpha( x(04) ) * ( 1 - x(20) ) ...
					- beta ( x(04) ) * x(20);

%% NKCC two-state model for marginal-baso

	dxdt(21)	=	+ beta2	( x(09), x(15), x(19) ) * ( 1 - x(21) ) ...
					- alpha2( x(08), x(14), x(18) ) * x(21);
                                       
%% Na Concentration ODE

 	dxdt(22)	=	( ...
						+ NFc ...                                           
                          * ( ...
                            + INaNaKATPFc                                ... % transporter K current
                            + INaFc                                      ... % Na channel current
                            + INCFc * jdg_NaFc                            ... % INCFc current
                            ) ...
					) ...
					/ ( F * WPL * NFc );				%NaZxPL

	dxdt(23)	=	( ...
                        - NFc ...
                          * ( ...
                            + INaNaKATPFc                                ... % transporter current
                            + INaFc                                      ... % Na channel current
                            + INCFc * jdg_NaFc                            ... % INCFc current
                            ) ...
					) ...
					/ ( F * WSY * NFc );				% NaZxSY
                                        
          dxdt(24)  =  0;%         +NMc * INCMa * jdg_Na2... +NMc *(- INCMa * jdg_Na2);
          dxdt(25)  =         0;
          
 %% NKCC two-state model for fibrocyte

	dxdt(26)	=	+ beta3	( x(07), x(13), x(23) ) * ( 1 - x(26) ) ...
					- alpha3( x(06), x(12), x(22) ) * x(26);
                                        