%% O
clear all;


%% 1. Number of cells per one model's segment and cell volume
NFc			= 168;	% fibrocyte
NIm			= 16;	% intermediate
NMc			= 40;	% marginal-cell
NHc			= 3;	% hair-cell

%% p[^ݒ
R			=	8.31447;						% Gas constant (J/K*mol)
T			=	310.15;							% Temperature		(Kelvin)
F			=	96485;							% Faraday constant (C/mol)

GNaKATPFc       =   2.2   *10^(-11);                 % conductance of NaKATP fibrocyte
GNCFc           =   0.6   *10^(-9);                  % conductance of NSC channel
GKFc            =   0     *10^(-12);                  % conductance of K channel
GNaFc           =   1.2   *10^(-9);   

GKIm		    = 147    *10^(-9);					% K   conductance of intermediate	(nS)
%GKvIm          =   0    *10^(-9);                  % Kv conductance of intermediate  (nS)
GNCIm           =  12    *10^(-9);                  % NSC conductance of intermediate (nS)

GNaKATPMb	    =   0.11 *10^(-9);                  % (block)*conductance of NaKATP marginal-baso
PNKCCMb		    =   0.1  *10^(-12);                 % NKCC rate
GClMb		    = 100    *10^(-9);                  % Cl  conductance of marginal-baso	(S)
GNCMb		    =   1    *10^(-9);                  % NSC conductance of marginal-baso	(S)

GKMa		    =  32    *10^(-9);                  % K   conductance of marginal-api	(S)
GNCMa           =   2    *10^(-9);                  % NSC conductance of marginal-api (S)

GKHa		    =   6.4  *10^(-9);                  % K   conductance of hair-api		(S)
GKHb		    =  40    *10^(-9);                  % K   conductance of hair-baso		(S)


KNa			=	0.04469;						% Constant in NKCC1 Equation
KK			=	0.00426;						% Constant in NKCC1 Equation
KCl			=	0.41329;						% Constant in NKCC1 Equation
KfFull		=	1.406;							% Constant in NKCC1 Equation
KbFull		=	4.025;							% Constant in NKCC1 Equation

tspan		=	[0, 4800]; 

initial_value = [ ...
	 0.009,  ...	% VFc	x(01)
	-0.08954,  ...	% VIm	x(02)
	-0.001292,  ...	% VMb	x(03)
	 0.0126,  ...	% VMa	x(04)
	-0.07613,  ...	% VHb	x(05)
	 0.002868,  ...	% KPL	x(06)
	 0.100,  ...	% KSY	x(07) !!!
	 0.00427, ...	% KIS	x(08)
	 0.131,  ...	% KMC	x(09)
	 0.160,  ...	% KEL	x(10)
	 0.133,  ...	% KHC	x(11)
	 0.1067,  ...	% ClPL	x(12)
	 0.070,  ...	% ClSY	x(13)
	 0.090,  ...	% ClIS	x(14)
	 0.112,  ...	% ClMC	x(15)
	 0.160,  ...	% ClEL	x(16)
	 0.070,  ...	% ClHC	x(17)
	 0.132,  ...	% NaIS	x(18)
	 0.00396, ...   % NaMC	x(19)
	 1,      ...    % Iks time  x(20)
	 0.5,  ...      % NKCCMb y  x(21)
     0.133,  ...    % NaPL   x(22)
     0.030,  ...    % NaSY   x(23) !!!
     0.003,  ...    % NaEL   x(24)
     0.003  ...     % NaHC   x(25)
     0.53   ...     % NKCCFc y  x(26)
];


%%
%options=odeset('OutputFcn',@odeplot);

[t,x]=ode15s(@single_bvp_ode,tspan,initial_value);


%% figure 1
figure;

subplot(3,2,1);plot(t,x(:, 6),'b', t, x(:,12),'g', t, x(:,22),'k')

xlabel('PL (mM)');

subplot(3,2,2);plot(t,x(:, 7),'b', t, x(:,13),'g', t, x(:,23),'k')

xlabel('Syn (mM)');

subplot(3,2,3);plot(t,x(:, 8),'b', t, x(:,14),'g', t, x(:,18),'k')

xlabel('IS (mM)');

subplot(3,2,4);plot(t,x(:, 9),'b', t, x(:,15),'g', t, x(:,19),'k')

xlabel('MC (mM)');

subplot(3,2,5);plot(t,x(:, 11),'b',t , x(:, 17),'g', t, x(:, 25),'k')

xlabel('HC (mM)');

subplot(3,2,6);plot(t,x(:, 10),'b',t , x(:, 16),'g', t, x(:, 24),'k')

xlabel('EL (mM)');


%% figure 2
figure;

subplot(1,3,1); plot ( t, x(:,01), t, x(:,02))

xlabel('VFc VIm potential');

subplot(1,3,2); plot ( t, x(:,03), t, x(:,04))

xlabel('VMb VMa potential');

subplot(1,3,3); plot ( t, x(:,01)-x(:,02)+x(:,03)-x(:,04)-x(:,05), t, x(:,05))

xlabel('VHa VHb potential');


%% figure3

figure;

%Intermediate cell current(K)
subplot(3,1,1);plot(...
          t, ...
	(10^(9))*GKIm* ( ( x(:, 08) ./ 0.0054 ).^(0.5) ).*( 1 ./ ( 1 + exp( ( x(:, 02) + 0.0592 ) ./ 0.0485 ) ) ) .*( x(:, 02) - ( R * T / F ) .* log( x(:,08) ./ x(:,07) ))...
	.* ( NIm ) , 'b',...
           t,...
          (10^(9))*(x(:,08)./(x(:,08)+x(:,18))).*GNCIm .* ( x(:,02) - ( R * T / F ).* log( ( x(:,08)+ x(:,18) ) ./ ( x(:,07)+ x(:,23) ) ) ).*(NIm),'k',...
          t, ...
	(10^(9))*0.045*GKIm* ( ( x(:, 08) ./ 0.0054 ).^(0.5) ).*( 1 ./ ( 1 + exp( ( x(:, 02) + 0.0592 ) ./ 0.0485 ) ) ) .*( x(:, 02) - ( R * T / F ) .* log( x(:,08) ./ x(:,07) ))...
	.* ( NIm ) , 'b',...
           t, -(10^(9))*GKHa*(-x(:,01)+x(:,02)-x(:,03)+x(:,04)+x(:,05)-( R * T / F )*log( x(: ,10) ./ x(: ,11)))*( NHc),'m'...
          )
xlabel('Kir4.1, NSCIm');

%Marginal-api current(K)
subplot(3,1,2);plot(t, (10^(9))*GKMa.*(x(:,20)).*(x(:,04)- (R*T/F)*log( x(:,10) ./ x(:,09)) ).*(NMc),'b',...
                                  t, (10^(9))* (x(:,09)./(x(:,09)+x(:,19) ) ).*GNCMa.* ( x(:,04) - ( R * T / F ).* log( ( x(:,10)+ x(:,24) ) ./ ( x(:,09)+ x(:,19) ) ) ).*(NMc),'k',...
                                  t, -(10^(9))*GKHa*(-x(:,01)+x(:,02)-x(:,03)+x(:,04)+x(:,05)-( R * T / F )*log( x(: ,10) ./ x(: ,11)))*( NHc),'m'...
)
xlabel('IKs NSCMa current');

%Fibrocytes current

subplot(3,1,3);plot(t, ...
                    (10^(9))*1600* 3 * GNaKATPFc ...
								* (...
                                    ( 1 ...
                                    ./ ( ...
                                        1 ...
                                        + 0.1245 * exp(  -0.1 *x(:,01) * F ./ ( R * T ) ) ...
                                        + 0.0365 * (( exp( 1000 * x(:,22) ./ 67.3 )  -1 ) ./ 7) .* exp( -x(:,01) .* F ./ ( R * T ) ) ...
                                      )...
                                    )...
                                ./ ( 1 + ( 0.01 ./ x(:,23) ).^1.5 ) ) ...
								.* ( x(:,06) ./ ( x(:,06) + 0.0015 ) ),'b',...
                    t,...
                    (10^(9))*1600*GNaFc * ( x(:,01)- ( R * T ./ F )*log( x(:,22) ./ x(:,23)) ),'g',...
                    t,...
                    (10^(9))*1600*GNCFc * ( x(:,01)- ( R * T ./ F )*log( (x(:,06)+ x(:,22)) ./ (x(:,07)+ x(:,23)) )),'r' ...
                    )
xlabel('NaKATPFc(Na),INaFc, INCFc');
                

%% fugure4

figure;

%Marginal-baso current(K)
subplot(3,1,1);plot(...
       t, ...%NaKATPase(K)
	-(10^(9))*2*GNaKATPMb ...
	* ( ...
		( ...
			1 ...
			./ ( ... 
				1 ...
				+ 0.1245 * exp( -0.1 * ( x(:,03) ) * F/(R*T) ) ...
				+ 0.0365 * ( ( ( exp( ( 1000 * x(:,18) ) / 67.3 ) ) - 1 ) / 7 ) .* exp( -( x(:,03) ) *F/(R*T) ) ) ...
		)  ...
		./ ( 1 + ( 0.01 ./ x(:,19) ).^1.5 ) ...
	) ...
	.* ( x(:,08) ./ ( x(:,08) + 0.0015 ) ) * (NMc) ,'r',...
      t, ...%NKCC(K)
	-(10^(9))*3*PNKCCMb * F ...
	* ( ...
		( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
	   )*NMc, 'b',...
        t,...%NCMb(K)
           (10^(9))*(x(:,08)./(x(:,08)+x(:,18))).*GNCMb.*(x(:,03)- (R*T/F)*log( (x(:,08)+ x(:,18))./(x(:,09)+ x(:,19)) )).*(NMc),'k',...
        t, ...%NaKATPasex0.05
	-(10^(9))*0.05*2*GNaKATPMb ...
	* ( ...
		( ...
			1 ...
			./ ( ... 
				1 ...
				+ 0.1245 * exp( -0.1 * ( x(:,03) ) * F/(R*T) ) ...
				+ 0.0365 * ( ( ( exp( ( 1000 * x(:,18) ) / 67.3 ) ) - 1 ) / 7 ) .* exp( -( x(:,03) ) *F/(R*T) ) ) ...
		)  ...
		./ ( 1 + ( 0.01 ./ x(:,19) ).^1.5 ) ...
	) ...
	.* ( x(:,08) ./ ( x(:,08) + 0.0015 ) ) * (NMc) ,'r',...
          t, ...%NKCCx0.05
	-(10^(9))*0.05*3*PNKCCMb * F ...
	* ( ...
		( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
	)*NMc, 'b',...
           t,...%Circulation current
           (10^(9))*GKHa*(-x(:,01)+x(:,02)-x(:,03)+x(:,04)+x(:,05)-( R * T / F )*log( x(: ,10) ./ x(: ,11)))*( NHc),'m',...
                   t,...%NCMb(K)
(...
           (10^(9))*(x(:,08)./(x(:,08)+x(:,18))).*GNCMb.*(x(:,03)- (R*T/F)*log( (x(:,08)+ x(:,18))./(x(:,09)+ x(:,19)) )).*(NMc)...
           ...%NaKATPase(K)x0.05
           -(10^(9))*0.05*2*GNaKATPMb ...
	* ( ...
		( ...
			1 ...
			./ ( ... 
				1 ...
				+ 0.1245 * exp( -0.1 * ( x(:,03) ) * F/(R*T) ) ...
				+ 0.0365 * ( ( ( exp( ( 1000 * x(:,18) ) / 67.3 ) ) - 1 ) / 7 ) .* exp( -( x(:,03) ) *F/(R*T) ) ) ...
		)  ...
		./ ( 1 + ( 0.01 ./ x(:,19) ).^1.5 ) ...
	) ...
	.* ( x(:,08) ./ ( x(:,08) + 0.0015 ) ) * (NMc) ...	
          ...%NKCC(K)x0.05
            -(10^(9))*0.05*3*PNKCCMb * F ...
	   * ( ...
	              ( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
	)*NMc...
)...
, 'g'...
           )
xlabel('(K) NaKATPMb NKCCMb NSCMb current');

%Marginal-baso current(Na)
subplot(3,1,2);plot(...
        t, ...%NaKATPase(Na)
	(10^(9))*(3)*GNaKATPMb ...
	* ( ...
		( ...
			1 ...
			./ ( ... 
				1 ...
				+ 0.1245 * exp( -0.1 * ( x(:,03) ) * F/(R*T) ) ...
				+ 0.0365 * ( ( ( exp( ( 1000 * x(:,18) ) / 67.3 ) ) - 1 ) / 7 ) .* exp( -( x(:,03) ) *F/(R*T) ) ) ...
		)  ...
		./ ( 1 + ( 0.01 ./ x(:,19) ).^1.5 ) ...
	) ...
	.* ( x(:,08) ./ ( x(:,08) + 0.0015 ) ) * (NMc) ,'r',...
          t, ...%NKCC(Na)
	-(10^(9))*3*PNKCCMb * F ...
	* ( ...
		( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
	   )*NMc, 'b',...
              t, ...%NaKATPase(Na)x0.05
	(10^(9))*3*0.05*GNaKATPMb ...
	* ( ...
		( ...
			1 ...
			./ ( ... 
				1 ...
				+ 0.1245 * exp( -0.1 * ( x(:,03) ) * F/(R*T) ) ...
				+ 0.0365 * ( ( ( exp( ( 1000 * x(:,18) ) / 67.3 ) ) - 1 ) / 7 ) .* exp( -( x(:,03) ) *F/(R*T) ) ) ...
		)  ...
		./ ( 1 + ( 0.01 ./ x(:,19) ).^1.5 ) ...
	) ...
	.* ( x(:,08) ./ ( x(:,08) + 0.0015 ) ) * (NMc) ,'r',...
          t, ...%NKCC(Na)x0.05
	-(10^(9))*3*0.05*PNKCCMb * F ...
	* ( ...
		( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
	   )*NMc, 'b',...
           t,...%NCMb(Na)
            (10^(9))*(x(:,18)./(x(:,08)+x(:,18))).*GNCMb.*(x(:,03)- (R*T/F)*log( (x(:,08)+ x(:,18))./(x(:,09)+ x(:,19)) )).*(NMc),'k',...
                          t, ...%NaKATPase(Na)x0.05
(...
	     (10^(9))*3*0.05*GNaKATPMb ...
	      * ( ...
		     ( ...
			1 ...
			./ ( ... 
				1 ...
				+ 0.1245 * exp( -0.1 * ( x(:,03) ) * F/(R*T) ) ...
				+ 0.0365 * ( ( ( exp( ( 1000 * x(:,18) ) / 67.3 ) ) - 1 ) / 7 ) .* exp( -( x(:,03) ) *F/(R*T) ) ) ...
		      )  ...
		./ ( 1 + ( 0.01 ./ x(:,19) ).^1.5 ) ...
	         ) ...
	         .* ( x(:,08) ./ ( x(:,08) + 0.0015 ) ) * (NMc)...
               ...%NKCC(Na)x0.05
	     -(10^(9))*3*0.05*PNKCCMb * F ...
	      * ( ...
		     ( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
	   )*NMc...
             ...%NCMb(Na)
            +(10^(9))*(x(:,18)./(x(:,08)+x(:,18))).*GNCMb.*(x(:,03)- (R*T/F)*log( (x(:,08)+ x(:,18))./(x(:,09)+ x(:,19)) )).*(NMc)...
 ),'g'...
            )
xlabel('(Na) NaKATPMb NKCCMb NSCMb current');
          
%Marginal-baso current(Cl)
subplot(3,1,3);plot(...
          t, ...%NKCC(Cl)
	(10^(9))*(6)*PNKCCMb * F ...
	* ( ...
		( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
	   )*NMc, 'b',...
           t, ...%NKCC(Cl)x0.05
	    (10^(9))*(6)*0.05*PNKCCMb * F ...
	     * ( ...
		( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
                    	   )*NMc, 'b',...
         t,...%ClCMb(Cl)
             (10^(9))*GClMb.*(x(:,03)- (R*T/F)*log( x(:,15) ./ x(:,14)) ).*(NMc),'y',...
                        t, ...%NKCC(Cl)x0.05
(...
	    (10^(9))*(6)*0.05*PNKCCMb * F ...
	     * ( ...
		( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
                    	   )*NMc...
            ...%ClCMb(Cl)
             +(10^(9))*GClMb.*(x(:,03)- (R*T/F)*log( x(:,15) ./ x(:,14)) ).*(NMc)...
   ),'g'...             
             )
 xlabel('(Cl) NKCCMb ClCMb current');
             
 %%
 %CIړʂ̂
 
 figure;

%Marginal-baso current(K)
subplot(3,1,1);plot(...
        t,...%NCMb(K)
-(...
           (10^(9))*(x(:,08)./(x(:,08)+x(:,18))).*GNCMb.*(x(:,03)- (R*T/F)*log( (x(:,08)+ x(:,18))./(x(:,09)+ x(:,19)) )).*(NMc)...
           ...%NaKATPase(K)x0.05
           -(10^(9))*0.05*2*GNaKATPMb ...
	* ( ...
		( ...
			1 ...
			./ ( ... 
				1 ...
				+ 0.1245 * exp( -0.1 * ( x(:,03) ) * F/(R*T) ) ...
				+ 0.0365 * ( ( ( exp( ( 1000 * x(:,18) ) / 67.3 ) ) - 1 ) / 7 ) .* exp( -( x(:,03) ) *F/(R*T) ) ) ...
		)  ...
		./ ( 1 + ( 0.01 ./ x(:,19) ).^1.5 ) ...
	) ...
	.* ( x(:,08) ./ ( x(:,08) + 0.0015 ) ) * (NMc) ...	
          ...%NKCC(K)x0.05
            -(10^(9))*0.05*3*PNKCCMb * F ...
	   * ( ...
	              ( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
	)*NMc...
)...
, 'b',...
       t,...%Circulation current
           -(10^(9))*GKHa*(-x(:,01)+x(:,02)-x(:,03)+x(:,04)+x(:,05)-( R * T / F )*log( x(: ,10) ./ x(: ,11)))*( NHc),'m',...
       t,...%NCMb(K)
-(...
           (10^(9))*(x(:,08)./(x(:,08)+x(:,18))).*GNCMb.*(x(:,03)- (R*T/F)*log( (x(:,08)+ x(:,18))./(x(:,09)+ x(:,19)) )).*(NMc)...
           ...%NaKATPase(K)x0.05
           -(10^(9))*0.05*2*GNaKATPMb ...
	* ( ...
		( ...
			1 ...
			./ ( ... 
				1 ...
				+ 0.1245 * exp( -0.1 * ( x(:,03) ) * F/(R*T) ) ...
				+ 0.0365 * ( ( ( exp( ( 1000 * x(:,18) ) / 67.3 ) ) - 1 ) / 7 ) .* exp( -( x(:,03) ) *F/(R*T) ) ) ...
		)  ...
		./ ( 1 + ( 0.01 ./ x(:,19) ).^1.5 ) ...
	) ...
	.* ( x(:,08) ./ ( x(:,08) + 0.0015 ) ) * (NMc) ...	
          ...%NKCC(K)x0.05
            -(10^(9))*0.05*3*PNKCCMb * F ...
	   * ( ...
	              ( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
	)*NMc...
)...
-(...
	     (10^(9))*3*0.05*GNaKATPMb ...
	      * ( ...
		     ( ...
			1 ...
			./ ( ... 
				1 ...
				+ 0.1245 * exp( -0.1 * ( x(:,03) ) * F/(R*T) ) ...
				+ 0.0365 * ( ( ( exp( ( 1000 * x(:,18) ) / 67.3 ) ) - 1 ) / 7 ) .* exp( -( x(:,03) ) *F/(R*T) ) ) ...
		      )  ...
		./ ( 1 + ( 0.01 ./ x(:,19) ).^1.5 ) ...
	         ) ...
	         .* ( x(:,08) ./ ( x(:,08) + 0.0015 ) ) * (NMc)...
               ...%NKCC(Na)x0.05
	     -(10^(9))*3*0.05*PNKCCMb * F ...
	      * ( ...
		     ( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
	   )*NMc...
             ...%NCMb(Na)
            +(10^(9))*(x(:,18)./(x(:,08)+x(:,18))).*GNCMb.*(x(:,03)- (R*T/F)*log( (x(:,08)+ x(:,18))./(x(:,09)+ x(:,19)) )).*(NMc)...
 ),'k'...
           )
xlabel('(K) total and circulation current');

%Marginal-baso current(Na)
subplot(3,1,2);plot(...
              t, ...%NaKATPase(Na)x0.05
-(...
	     (10^(9))*3*0.05*GNaKATPMb ...
	      * ( ...
		     ( ...
			1 ...
			./ ( ... 
				1 ...
				+ 0.1245 * exp( -0.1 * ( x(:,03) ) * F/(R*T) ) ...
				+ 0.0365 * ( ( ( exp( ( 1000 * x(:,18) ) / 67.3 ) ) - 1 ) / 7 ) .* exp( -( x(:,03) ) *F/(R*T) ) ) ...
		      )  ...
		./ ( 1 + ( 0.01 ./ x(:,19) ).^1.5 ) ...
	         ) ...
	         .* ( x(:,08) ./ ( x(:,08) + 0.0015 ) ) * (NMc)...
               ...%NKCC(Na)x0.05
	     -(10^(9))*3*0.05*PNKCCMb * F ...
	      * ( ...
		     ( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
	   )*NMc...
             ...%NCMb(Na)
            +(10^(9))*(x(:,18)./(x(:,08)+x(:,18))).*GNCMb.*(x(:,03)- (R*T/F)*log( (x(:,08)+ x(:,18))./(x(:,09)+ x(:,19)) )).*(NMc)...
 ),'k'...
            )
xlabel('(Na) total current');
          
%Marginal-baso current(Cl)
subplot(3,1,3);plot(...
           t, ...%NKCC(Cl)x0.05
-(...
	    (10^(9))*(6)*0.05*PNKCCMb * F ...
	     * ( ...
		( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
                    	   )*NMc...
            ...%ClCMb(Cl)
             +(10^(9))*GClMb.*(x(:,03)- (R*T/F)*log( x(:,15) ./ x(:,14)) ).*(NMc)...
   ),'g',...
   t,...
-(...
	    (10^(9))*(6)*0.05*PNKCCMb * F ...
	     * ( ...
		( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
                    	   )*NMc...
            ...%ClCMb(Cl)
             +(10^(9))*GClMb.*(x(:,03)- (R*T/F)*log( x(:,15) ./ x(:,14)) ).*(NMc)...
   )...
-(...
	     (10^(9))*3*0.05*GNaKATPMb ...
	      * ( ...
		     ( ...
			1 ...
			./ ( ... 
				1 ...
				+ 0.1245 * exp( -0.1 * ( x(:,03) ) * F/(R*T) ) ...
				+ 0.0365 * ( ( ( exp( ( 1000 * x(:,18) ) / 67.3 ) ) - 1 ) / 7 ) .* exp( -( x(:,03) ) *F/(R*T) ) ) ...
		      )  ...
		./ ( 1 + ( 0.01 ./ x(:,19) ).^1.5 ) ...
	         ) ...
	         .* ( x(:,08) ./ ( x(:,08) + 0.0015 ) ) * (NMc)...
               ...%NKCC(Na)x0.05
	     -(10^(9))*3*0.05*PNKCCMb * F ...
	      * ( ...
		     ( ...
			KfFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KNa * 1000 .* ( x( :, 18) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) ...
						+ KNa * 1000 .* ( x( :, 18) ) * KCl * 1000 .* ( x( :, 14) ) * KK * 1000 .* ( x( :, 08) ) * KCl * 1000 .* ( x( :, 14) ) ...
					) ...
				) ...
			) ...
		)	...	%KfFull*p(E1NaClKCl)
		.* ( x( :, 21 ) ) ...
		- ( ...
			KbFull ...
			.* ( ...
				KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
				.* ( ...
					1 ...
					./ ( ...
						1 ...
						+ KCl * 1000 .* ( x( :, 15) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) ...
						+ KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
						+ KNa * 1000 .* ( x( :, 19) ) * KCl * 1000 .* ( x( :, 15) ) * KK  * 1000 .* ( x( :, 09) ) * KCl * 1000 .* ( x( :, 15) ) ...
					) ...
				) ...
			) ...
		)...	%KbFull*p(E2NaClKCl)
		.* ( 1 - x( :, 21 ) )...
	   )*NMc...
             ...%NCMb(Na)
            +(10^(9))*(x(:,18)./(x(:,08)+x(:,18))).*GNCMb.*(x(:,03)- (R*T/F)*log( (x(:,08)+ x(:,18))./(x(:,09)+ x(:,19)) )).*(NMc)...
 ),'k',...
       t,...%Circulation current
           -(10^(9))*GKHa*(-x(:,01)+x(:,02)-x(:,03)+x(:,04)+x(:,05)-( R * T / F )*log( x(: ,10) ./ x(: ,11)))*( NHc),'m'... 
             )
 xlabel('(Cl) total current');
 

%%

figure;

subplot(3,2,1); plot(t,x(:, 8),t,x(:, 14))

xlabel('IS K,Cl-Conc.');

subplot(3,2,2); plot(t,x(:, 9),t,x(:,15))

xlabel('MC K,Cl-Conc.');

subplot(3,1,2);plot(t,x(:,2),t,x(:,3),t,x(:,4))

xlabel('VIm VMb VMa');

subplot(3,1,3);plot(t,x(:,1)-x(:,2),'r',t,x(:,1)-x(:,2)+x(:,3),'g', t,x(:,1)-x(:,2)+x(:,3)-x(:,4), 'k')

xlabel('ISP,MCP,EP');




